- Add filters to search
- Think about model view

- Set up proper migrations

- Add python library documentation

- Upload some datasets

- Write Java library

- Add CCD0 summary tree
- Add simple tree ESS
- Add more BEAST2 libraries

- Author email
